Enum FilterBlockOption
pub enum FilterBlockOption {
Range {
from_block: Option<BlockNumberOrTag>,
to_block: Option<BlockNumberOrTag>,
},
AtBlockHash(FixedBytes<32>),
}Expand description
Represents the target range of blocks for the filter
Variants
Range
Represents a range of blocks with optional from and to blocks
Note: ranges are considered to be inclusive
Fields

from_block: Option<BlockNumberOrTag>The block number or tag this filter should start at.

to_block: Option<BlockNumberOrTag>The block number or that this filter should end at.
AtBlockHash(FixedBytes<32>)
The hash of the block if the filter only targets a single block
Implementations
impl FilterBlockOption
impl FilterBlockOption
pub const fn get_to_block(&self) -> Option<&BlockNumberOrTag>
pub const fn get_to_block(&self) -> Option<&BlockNumberOrTag>
Returns the to_block value, if any
pub const fn get_from_block(&self) -> Option<&BlockNumberOrTag>
pub const fn get_from_block(&self) -> Option<&BlockNumberOrTag>
Returns the from_block value, if any
pub const fn as_range(
&self,
) -> (Option<&BlockNumberOrTag>, Option<&BlockNumberOrTag>)
pub const fn as_range( &self, ) -> (Option<&BlockNumberOrTag>, Option<&BlockNumberOrTag>)
Returns the range (from_block, to_block) if this is a range filter.
pub const fn as_block_hash(&self) -> Option<&FixedBytes<32>>
pub const fn as_block_hash(&self) -> Option<&FixedBytes<32>>
Returns the block hash if this is a block hash filter.
pub const fn is_block_hash(&self) -> bool
pub const fn is_block_hash(&self) -> bool
Returns true if this is a block hash filter.
pub fn ensure_valid_block_range(&self) -> Result<(), FilterBlockError>
pub fn ensure_valid_block_range(&self) -> Result<(), FilterBlockError>
Ensure block range validity
pub const fn with_from_block(
&self,
block: BlockNumberOrTag,
) -> FilterBlockOption
pub const fn with_from_block( &self, block: BlockNumberOrTag, ) -> FilterBlockOption
Sets the block number this range filter should start at.
pub const fn with_to_block(&self, block: BlockNumberOrTag) -> FilterBlockOption
pub const fn with_to_block(&self, block: BlockNumberOrTag) -> FilterBlockOption
Sets the block number this range filter should end at.
pub const fn with_block_hash(&self, hash: FixedBytes<32>) -> FilterBlockOption
pub const fn with_block_hash(&self, hash: FixedBytes<32>) -> FilterBlockOption
Pins the block hash this filter should target.