pub struct ReceiptExtractor { /* private fields */ }Expand description
Utility to extract receipts from extrinsics.
Implementations
Sourceimpl ReceiptExtractor
impl ReceiptExtractor
Sourcepub async fn new(api: OnlineClient<SrcChainConfig>) -> Result<Self, ClientError>
pub async fn new(api: OnlineClient<SrcChainConfig>) -> Result<Self, ClientError>
Create a new ReceiptExtractor.
Sourcepub async fn new_with_custom_address_recovery(
api: OnlineClient<SrcChainConfig>,
recover_eth_address_fn: Arc<dyn Fn(&TransactionSigned) -> Result<H160, ()> + Send + Sync>,
) -> Result<Self, ClientError>
pub async fn new_with_custom_address_recovery( api: OnlineClient<SrcChainConfig>, recover_eth_address_fn: Arc<dyn Fn(&TransactionSigned) -> Result<H160, ()> + Send + Sync>, ) -> Result<Self, ClientError>
Create a new ReceiptExtractor with custom Ethereum address recovery logic.
Use ReceiptExtractor::new if the default Ethereum address recovery
logic (TransactionSigned::recover_eth_address based) is enough.
Sourcepub fn is_before_first_evm_block(
&self,
block_number: SubstrateBlockNumber,
) -> bool
pub fn is_before_first_evm_block( &self, block_number: SubstrateBlockNumber, ) -> bool
Check if the block is before the first_evm_block floor.
When sentinel (u32::MAX), no blocks are rejected (permissive default).
Sourcepub fn set_first_evm_block(&self, block_number: SubstrateBlockNumber)
pub fn set_first_evm_block(&self, block_number: SubstrateBlockNumber)
Set the first EVM block. Only stores if lower than the current value.
Sourcepub fn first_evm_block(&self) -> Option<SubstrateBlockNumber>
pub fn first_evm_block(&self) -> Option<SubstrateBlockNumber>
The auto-discovered first EVM block, or None if not yet discovered.
Sourcepub async fn extract_from_block(
&self,
block: &SubstrateBlock,
) -> Result<Vec<(TransactionSigned, ReceiptInfo)>, ClientError>
pub async fn extract_from_block( &self, block: &SubstrateBlock, ) -> Result<Vec<(TransactionSigned, ReceiptInfo)>, ClientError>
Extract receipts from block.
Sourcepub async fn extract_from_block_with_eth_hash(
&self,
block: &SubstrateBlock,
eth_block_hash: H256,
) -> Result<Vec<(TransactionSigned, ReceiptInfo)>, ClientError>
pub async fn extract_from_block_with_eth_hash( &self, block: &SubstrateBlock, eth_block_hash: H256, ) -> Result<Vec<(TransactionSigned, ReceiptInfo)>, ClientError>
Extract receipts from block, using a pre-fetched ethereum block hash.
Fetches block events once in a single pass before building receipts.
Sourcepub async fn extract_from_transaction(
&self,
block: &SubstrateBlock,
transaction_index: usize,
) -> Result<(TransactionSigned, ReceiptInfo), ClientError>
pub async fn extract_from_transaction( &self, block: &SubstrateBlock, transaction_index: usize, ) -> Result<(TransactionSigned, ReceiptInfo), ClientError>
Extract a TransactionSigned and a ReceiptInfo for a specific transaction in a
SubstrateBlock
Sourcepub async fn get_ethereum_block_hash(
&self,
block_hash: &H256,
block_number: u64,
) -> Option<H256>
pub async fn get_ethereum_block_hash( &self, block_hash: &H256, block_number: u64, ) -> Option<H256>
Get the Ethereum block hash for the Substrate block with specific hash.